Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(195)

Unified Diff: src/debug/mirrors.js

Issue 2069823003: [wasm] Enable wasm frame inspection for debugging (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@split-wasm-debug
Patch Set: Add two DCHECKs Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/debug/debug-scopes.cc ('k') | src/frames.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/debug/mirrors.js
diff --git a/src/debug/mirrors.js b/src/debug/mirrors.js
index 1aaa22aa7ef73faba17ed5960fa915ec1cb2444f..b91b10cb7fb6495fb7a112e4d8ea0e3b7cde3b6c 100644
--- a/src/debug/mirrors.js
+++ b/src/debug/mirrors.js
@@ -1091,6 +1091,11 @@ UnresolvedFunctionMirror.prototype.name = function() {
};
+UnresolvedFunctionMirror.prototype.debugName = function() {
+ return this.value_;
+};
+
+
UnresolvedFunctionMirror.prototype.inferredName = function() {
return UNDEFINED;
};
@@ -1620,13 +1625,14 @@ InternalPropertyMirror.prototype.value = function() {
var kFrameDetailsFrameIdIndex = 0;
var kFrameDetailsReceiverIndex = 1;
var kFrameDetailsFunctionIndex = 2;
-var kFrameDetailsArgumentCountIndex = 3;
-var kFrameDetailsLocalCountIndex = 4;
-var kFrameDetailsSourcePositionIndex = 5;
-var kFrameDetailsConstructCallIndex = 6;
-var kFrameDetailsAtReturnIndex = 7;
-var kFrameDetailsFlagsIndex = 8;
-var kFrameDetailsFirstDynamicIndex = 9;
+var kFrameDetailsScriptIndex = 3;
+var kFrameDetailsArgumentCountIndex = 4;
+var kFrameDetailsLocalCountIndex = 5;
+var kFrameDetailsSourcePositionIndex = 6;
+var kFrameDetailsConstructCallIndex = 7;
+var kFrameDetailsAtReturnIndex = 8;
+var kFrameDetailsFlagsIndex = 9;
+var kFrameDetailsFirstDynamicIndex = 10;
var kFrameDetailsNameIndex = 0;
var kFrameDetailsValueIndex = 1;
@@ -1643,12 +1649,13 @@ var kFrameDetailsFlagInlinedFrameIndexMask = 7 << 2;
* 0: Id
* 1: Receiver
* 2: Function
* 3: Argument count
* 4: Local count
* 5: Source position
* 6: Construct call
* 7: Is at return
* 8: Flags (debugger frame, optimized frame, inlined frame index)
* Arguments name, value
* Locals name, value
* Return value if any
@@ -1680,6 +1687,12 @@ FrameDetails.prototype.func = function() {
};
+FrameDetails.prototype.script = function() {
+ %CheckExecutionState(this.break_id_);
+ return this.details_[kFrameDetailsScriptIndex];
+};
+
+
FrameDetails.prototype.isConstructCall = function() {
%CheckExecutionState(this.break_id_);
return this.details_[kFrameDetailsConstructCallIndex];
@@ -1643,12 +1649,13 @@ var kFrameDetailsFlagInlinedFrameIndexMask = 7 << 2;
* 1: Receiver
* 2: Function
- * 3: Argument count
- * 4: Local count
- * 5: Source position
- * 6: Construct call
- * 7: Is at return
- * 8: Flags (debugger frame, optimized frame, inlined frame index)
+ * 3: Script
+ * 4: Argument count
+ * 5: Local count
+ * 6: Source position
+ * 7: Construct call
+ * 8: Is at return
+ * 9: Flags (debugger frame, optimized frame, inlined frame index)
* Arguments name, value
* Locals name, value
« no previous file with comments | « src/debug/debug-scopes.cc ('k') | src/frames.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698